@@ -226,11 +226,11 @@ class DistroRepository(Linux):
     def _findLatestFile(self, dirs, reMatch, keyfunc):
         """Find latest file in dirs, which match by reMatch,
         comparable part get by keyfunc"""
-        existsdirs = filter(path.exists, dirs)
-        listimgs = reduce(lambda x, y: x + map(
+        existsdirs = list(filter(path.exists, dirs))
+        listimgs = reduce(lambda x, y: x + list(map(
             lambda x: reMatch.search(
                 path.join(y, x)),
-            listDirectory(y)),
+            listDirectory(y))),
                           existsdirs, [])
         listimgs = [x for x in listimgs if x]
         if listimgs:
