@@ -562,7 +562,7 @@ class VariableOsInstallNetRouteData(NetHelper, TableVariable):
         else:
             wrapper = lambda x: x
 
-        self.value = self.set(map(wrapper,value))
+        self.value = self.set([wrapper(x) for x in value])
         self.wasSet = True
         self.invalid = False
         # run check
